@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::YANICK;
 BEGIN {
   $Dist::Zilla::PluginBundle::YANICK::AUTHORITY = 'cpan:YANICK';
 }
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.21.1';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.22.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -12,6 +12,8 @@ use strict;
 
 use Moose;
 
+use Dist::Zilla;
+
 with qw/
     Dist::Zilla::Role::PluginBundle::Easy
     Dist::Zilla::Role::PluginBundle::Config::Slicer
@@ -28,16 +30,25 @@ has "doap_changelog" => (
     },
 );
 
+
+
+
+
+
 sub configure {
     my ( $self ) = @_;
     my $arg = $self->payload;
 
-    my $release_branch = 'releases';
-    my $upstream       = 'github';
+    my $release_branch = $arg->{release_branch} || 'releases';
+    my $dev_branch     = $arg->{dev_branch}     || 'master';
+    my $upstream       = $arg->{upstream}       || 'github';
 
     my %mb_args;
     $mb_args{mb_class} = $arg->{mb_class} if $arg->{mb_class};
-    $self->add_plugins([ 'ModuleBuild', \%mb_args ]);
+
+    my $builder = $arg->{builder} || 'MakeMaker';
+
+    $self->add_plugins([ $builder, ( \%mb_args ) x ($builder eq 'ModuleBuild' ) ]);
 
     $self->add_plugins(
         qw/ 
@@ -99,7 +110,11 @@ sub configure {
             minor => 'NEW FEATURES, ENHANCEMENTS',
             revision => 'BUG FIXES, DOCUMENTATION, STATISTICS',
         } ],
-        [ 'ChangeStats::Git' => { group => 'STATISTICS' } ],
+        [ 'ChangeStats::Git' => { 
+                group => 'STATISTICS',
+                develop_branch => $dev_branch,
+                release_branch => $release_branch,
+            } ],
         'Git::Commit',
     );
 
@@ -108,7 +123,7 @@ sub configure {
     }
     else {
         $self->add_plugins(
-            [ 'Git::Push' => { push_to    => $upstream . ' master releases' } ],
+            [ 'Git::Push' => { push_to    => join ' ', $upstream, $dev_branch, $release_branch} ],
             qw/ UploadToCPAN /, 
         );
 
@@ -170,7 +185,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.21.1
+version 0.22.0
 
 =head1 DESCRIPTION
 
@@ -184,7 +199,7 @@ his distributions. It's roughly equivalent to
 
     [CoalescePod]
 
-    [ModuleBuild]
+    [MakeMaker]
 
     [InstallGuide]
     [Covenant]
@@ -288,6 +303,10 @@ L<Dist::Zilla::Plugin::Twitter>.
 
 Can also be triggered via the I<FAKE> environment variable.
 
+=head3 builder 
+
+C<ModuleBuild> or C<MakeMaker>. Defaults to C<MakeMaker>.
+
 =head3 mb_class
 
 Passed to C<ModuleBuild> plugin.
@@ -305,6 +324,24 @@ If a tweet should be sent. Defaults to C<true>.
 If the DOAP plugin should generate the project history
 off the changelog. Defaults to I<true>.
 
+=head3 dev_branch
+
+Master development branch.
+
+Defaults to C<master>.
+
+=head3 release_branch
+
+Branch on which the CPAN images are commited.
+
+Defaults to C<releases>.
+
+=head3 upstream
+
+The name of the upstream repo.
+
+Defaults to C<github>.
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
